@@ -11,12 +11,14 @@ from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.db import models
 from django.db.models.fields.proxy import OrderWrt
+from django.db.models.fields.files import FileField
 from django.forms.models import model_to_dict
 from django.utils.text import format_lazy
 from django.utils.encoding import smart_str
 from . import exceptions
 from .manager import EditSuggestionDescriptor
 from django.contrib.auth.models import PermissionDenied
+from django.db.models.fields.related import ForeignKey
 
 registered_models = {}
 
@@ -45,6 +47,8 @@ class EditSuggestion(object):
             custom_model_name=None,
             app=None,
             related_name=None,
+            signals=None,
+            attrs_to_be_copied=[]
     ):
         self.change_status_condition = change_status_condition
         self.post_publish = post_publish
@@ -58,7 +62,9 @@ class EditSuggestion(object):
         self.related_name = related_name
         self.excluded_fields = excluded_fields if excluded_fields else []
         self.edit_suggestion_model = None  # will be declared in finalize method
-        self.tracked_fields = {'simple': [], 'm2m': []}  # filled up in set_tracked_fields method
+        self.tracked_fields = {'simple': [], 'foreign': [], 'm2m': []}  # filled up in set_tracked_fields method
+        self.signals = signals
+        self.attrs_to_be_copied = attrs_to_be_copied
         try:
             if isinstance(bases, six.string_types):
                 raise TypeError
@@ -99,6 +105,15 @@ class EditSuggestion(object):
         setattr(sender, self.manager_name, descriptor)
         sender._meta.edit_suggestion_manager_attribute = self.manager_name
         models.signals.pre_save.connect(self.pre_save_edit_suggestion, self.edit_suggestion_model, weak=False)
+        # set up custom parent model signals
+        if self.signals:
+            for signal_name, signal_handlers in self.signals.items():
+                signal_instance = getattr(models.signals, signal_name)
+                for signal_handler in signal_handlers:
+                    signal_instance.connect(signal_handler, self.edit_suggestion_model, weak=False)
+        # copy attributes
+        for attr in self.attrs_to_be_copied:
+            setattr(self.edit_suggestion_model, attr, getattr(sender, attr))
 
     def get_edit_suggestion_model_name(self, model):
         if not self.custom_model_name:
@@ -124,11 +139,14 @@ class EditSuggestion(object):
 
     def set_tracked_fields(self, copied_fields):
         self.tracked_fields['m2m'] = [f for f in self.m2m_fields]
-        for field_name in copied_fields.keys():
+        for field_name, field in copied_fields.items():
             # exclude id and m2m fields
             if field_name == 'id' or field_name in [f['name'] for f in self.tracked_fields['m2m']]:
                 continue
-            self.tracked_fields['simple'].append(field_name)
+            if field.__class__ == ForeignKey:
+                self.tracked_fields['foreign'].append(field_name)
+            else :
+                self.tracked_fields['simple'].append(field_name)
 
     def create_edit_suggestion_model(self, model):
         """
@@ -298,13 +316,13 @@ class EditSuggestion(object):
                 raise PermissionDenied('User not allowed to publish the edit suggestion')
             for updatable_field in self.tracked_fields['simple']:
                 setattr(instance.edit_suggestion_parent, updatable_field, getattr(instance, updatable_field))
+            for updatable_field in self.tracked_fields['foreign']:
+                setattr(instance.edit_suggestion_parent, updatable_field, getattr(instance, updatable_field))
             # set m2m fields
             for m2m_field in self.tracked_fields['m2m']:
                 parent_m2m_field = getattr(instance.edit_suggestion_parent, m2m_field['name'])
                 instance_m2m_field = getattr(instance, m2m_field['name'])
                 if 'through' in m2m_field:
-
-
                     filter_dict = {}
                     filter_dict[m2m_field['through']['self_field']] = instance.edit_suggestion_parent
                     # need to filter manually
@@ -405,13 +423,9 @@ def transform_field(field):
         field.__class__ = models.BigIntegerField
     elif isinstance(field, models.AutoField):
         field.__class__ = models.IntegerField
-
     elif isinstance(field, models.FileField):
-        # Don't copy file, just path.
-        if getattr(settings, "EDIT_SUGGESTION_FILEFIELD_TO_CHARFIELD", False):
-            field.__class__ = models.CharField
-        else:
-            field.__class__ = models.TextField
+       # file fields are handled normally
+       field = field
 
     #  instance shouldn't change create/update timestamps
     field.auto_now = False
@@ -436,7 +450,8 @@ class EditSuggestionChanges(object):
         changed_fields = []
         old_values = model_to_dict(self.edit_suggestion_parent)
         current_values = model_to_dict(self)
-        for field in self.edit_suggestion_tracked_fields['simple'] + [f['name'] for f in self.edit_suggestion_tracked_fields['m2m']]:
+        fields_to_check = self.edit_suggestion_tracked_fields['simple'] + self.edit_suggestion_tracked_fields['foreign'] + [f['name'] for f in self.edit_suggestion_tracked_fields['m2m']]
+        for field in fields_to_check :
             if field in old_values and old_values[field] != current_values[field]:
                 change = ModelChange(field, old_values[field], current_values[field])
                 changes.append(change)
